/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 * 
 * This file is part of de.bsvrz.pua.prot.
 * 
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.bsvrz.pua.prot.client.dataobject;

import de.bsvrz.pua.prot.util.attributes.AttributeGroupDescription;

/**
 * Fasst Informationen über eine Attributgruppen-Spalte des Ergebnisdatensatzes zusammen. Wird im Administrationsdatensatz {@link
 * de.bsvrz.pua.prot.client.dataobject.ProtocolAdministrationData} verwendet.
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class AttributeGroupColumn extends Column {

	private static final long serialVersionUID = -3297812671747003581L;

	private long _objectId;

	private long _attributeGroupId;

	private long _aspectId;

	private short _simVar;

	/** @param atg Attributgruppenbeschreibung auf der die Spalte basiert. */
	public AttributeGroupColumn(AttributeGroupDescription atg) {
		super(ColumnType.ATTRIBUTE_GROUP, atg.qualifier.attributeGroup.getName(), atg.qualifier.attributeGroup.getId(), atg.getColumnName());
		_objectId = (atg.qualifier.object != null) ? atg.qualifier.object.getId() : -1;
		_attributeGroupId = atg.qualifier.attributeGroup.getId();
		_aspectId = atg.qualifier.aspect.getId();
		_simVar = atg.qualifier.simVar;
	}

	/** @return Returns the aspectId. */
	public long getAspectId() {
		return _aspectId;
	}

	/** @return Returns the attributeGroupId. */
	public long getAttributeGroupId() {
		return _attributeGroupId;
	}

	/** @return Returns the objectId. */
	public long getObjectId() {
		return _objectId;
	}

	/** @return Returns the simVar. */
	public short getSimVar() {
		return _simVar;
	}
}
