/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 * 
 * This file is part of de.bsvrz.pua.prot.
 * 
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.bsvrz.pua.prot.util.attributes;


/**
 * Kennzeichnet Elemente aus dem Datenkatalog, d.h. Attributgruppen und reale Attribute. (Im Gegensatz zu temporären Attributen, die nicht im Datenkatatlog
 * vorkommen). Dieses Interface dient dazu, Hashtables mit Objekten des Typs {@link de.bsvrz.pua.prot.util.attributes.RealAttributeDescription} und {@link
 * de.bsvrz.pua.prot.processing.archivebuffer.RealArchiveAttribute} füllen zu können.<br> Bsp:<br> <code>HashSet&lt;RealElement&gt; table = new
 * Hashtable&lt;RealElement&gt;();<br> RealAttributeDescription rad = new RealAlltributeDescription();<br> table.put(rad);<br> boolean b = table.contains(new
 * RealArchiveAttribute(rad, ...);<br> b</code> hat den Wert true!
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public interface RealElement {

	/**
	 * Zeigt an ob die Datenaufbereitung Daten für dieses Attribut auffüllen soll.
	 *
	 * @return <code>true</code> falls Daten durch die Datenaufbereitung aufgefüllt werden sollen.
	 */
	public boolean padData();

	/**
	 * Gibt den Index des verwendeten Alias an.
	 * @return Index des verwendeten Alias-Segments oder -1 falls keine Aliase verwendet werden.
	 */
	int getIndex();
}
